#ifndef __EMITTED_VALIDATE_H
#define __EMITTED_VALIDATE_H

#include <cassert>
#include <cstdarg>
#include <fstream>
#include <sstream>

typedef void (*feedback_function)(const char*, ...);

const int EXITCODE_AC = 0;
const int EXITCODE_WA = 0;

// declare a constant to be used as user_out.
const std::string FILENAME_USER_OUTPUT = "user_out";
// declare a constant to be used as input.
const std::string FILENAME_INPUT = "input";

#define USAGE "./%s\n"
// we have to define USAGE as dummy because we don't want to modify the lib. too much.

std::ifstream judge_in, judge_ans;
// another ifstream must be used for user_out;
std::ifstream user_out;

char *feedbackdir = NULL;

void vreport_feedback(const char* msg, va_list pvar) {
    assert(stderr);
    vfprintf(stderr, msg, pvar);
}

void report_feedback(const char* msg, ...) {
    va_list pvar;
    va_start(pvar, msg);
    vreport_feedback(msg, pvar);
}

void judge_message(const char* msg, ...) {
    va_list pvar;
    va_start(pvar, msg);
    vreport_feedback(msg, pvar);
}

void judge_error(const char* msg, ...) {
    va_list pvar;
    va_start(pvar, msg);
    vreport_feedback(msg, pvar);
    assert(0);
}

// cleaning up.
void cleanup() {
    fflush(stderr);
    fclose(stderr);
    fflush(stdout);
    fclose(stdout);
    judge_in.close();
    user_out.close();
}

// write another function ``scoring()`` for ac or wa.
void scoring(double score) {
    fprintf(stdout, "%.f", score + 1e-9);
}

void accept() {
    scoring(100.);
    cleanup();
    exit(EXITCODE_AC);
}

void accept_with_score(double scorevalue) {
    scoring(scorevalue);
    cleanup();
    exit(EXITCODE_AC);
}

void wrong_answer(const char* msg, ...) {
    va_list pvar;
    va_start(pvar, msg);
    vreport_feedback(msg, pvar);
    scoring(0.);
    cleanup();
    exit(EXITCODE_WA);
}

void init_io() {
    judge_in.open(FILENAME_INPUT, std::ios_base::in);
    if(judge_in.fail()) {
        judge_error("failed to open input file.\n");
    }
    user_out.open(FILENAME_USER_OUTPUT, std::ios_base::in);
    if(user_out.fail()) {
        judge_error("failed to open user output file.\n");
    }
    judge_ans.open("answer", std::ios_base::in);
    if(judge_ans.fail()) {
        judge_error("failed to open answer file.\n");
    }
}
using namespace std;
typedef long long ll;
ll n, ans_v, v, a, b, c;
bool check(istream &inf, istream &ans, istream &ouf, feedback_function waf) {
    inf >> n;
    ans >> ans_v;
    if (!(ouf >> v >> a >> b >> c))
        waf("Du lieu ra khong dung dinh dang.");
    if (v != ans_v)
        waf("Ket qua sai ve the tich. Dung: %lld, Tra loi: %lld.", ans_v, v);
    ll dt = a * b + b * c + c * a;
    ll tt = a * b * c;
    if (dt > n)
        waf("Dien tich vuot qua so luong cho phep (%lld vs %lld).", n, dt);
    if (tt != v)
        waf("Ket qua sai kich thuoc ba chieu (%lld, %lld, %lld).", a, b, c);
    string S;
    if (ouf >> S)
        waf("Du lieu ra khong dung dinh dang.");
    judge_message("OK. The tich: %lld, kich thuoc ba chieu la (%lld, %lld, %lld).", v, a, b, c);
    return 1;
}
#endif

int main(void) {
    init_io();
    check(judge_in, judge_ans, user_out, wrong_answer);
    accept();
}
